smart_city_registry v5.0.2 SmartCity.Registry.Dataset.Technical View Source
A struct defining technical metadata on a registry event message.
Link to this section Summary
Functions
Returns a new SmartCity.Registry.Dataset.Technical.
Can be created from Map with string or atom keys.
Raises an ArgumentError when passed invalid input
Link to this section Types
Link to this type
t()
View Sourcet() :: %SmartCity.Registry.Dataset.Technical{
allow_duplicates: not_required(boolean()),
authHeaders: not_required(map()),
authUrl: String.t(),
cadence: not_required(String.t()),
credentials: term(),
dataName: String.t(),
orgId: not_required(String.t()),
orgName: String.t(),
partitioner: not_required(%{type: String.t(), query: String.t()}),
private: not_required(boolean()),
protocol: not_required([String.t()]),
schema: not_required([map()]),
sourceFormat: String.t(),
sourceHeaders: not_required(map()),
sourceQueryParams: not_required(map()),
sourceType: not_required(String.t()),
sourceUrl: String.t(),
systemName: String.t(),
transformations: not_required(list()),
validations: not_required(list())
}
Link to this section Functions
Returns a new SmartCity.Registry.Dataset.Technical.
Can be created from Map with string or atom keys.
Raises an ArgumentError when passed invalid input
Parameters
msg: Map with string or atom keys that defines the dataset's technical metadata
Required Keys
- dataName
- orgName
- systemName
- sourceUrl
- sourceFormat
sourceType will default to "remote"
cadence will default to "never"